@@ -43,3 +43,13 @@ void SettingsDialog::defaultChannelsFeedUrl()
 {
     ui->feedUrl->setText(CHANNELS_FEED_URL);
 }
+
+bool SettingsDialog::isShowRecentlyPlayedSongs() const
+{
+    return ui->recentlyPlayedSongs->isChecked();
+}
+
+void SettingsDialog::setShowRecentlyPlayedSongs(bool b)
+{
+    ui->recentlyPlayedSongs->setChecked(b);
+}
